@@ -55,6 +55,8 @@ struct NautilusVolumeMonitorClass {
 				   	 const NautilusVolume	*volume);
 	void (* volume_unmounted) 	(NautilusVolumeMonitor	*monitor,
 				   	 const NautilusVolume	*volume);
+
+	void (* removable_volumes_changed) (NautilusVolumeMonitor *monitor);
 };
 
 typedef enum {
@@ -69,12 +71,12 @@ typedef enum {
 	NAUTILUS_DEVICE_ZIP_DRIVE,
 	NAUTILUS_DEVICE_SMB,
 	NAUTILUS_DEVICE_APPLE,
-	NAUTILUS_DEVICE_WINDOWS,
+	NAUTILUS_DEVICE_WINDOWS
 } NautilusDeviceType;
 
 typedef gboolean (* NautilusEachVolumeCallback) (const NautilusVolume *, gpointer callback_data);
 
-GtkType                  nautilus_volume_monitor_get_type                   (void);
+GType                    nautilus_volume_monitor_get_type                   (void);
 NautilusVolumeMonitor  	*nautilus_volume_monitor_get                        (void);
 void                     nautilus_volume_monitor_mount_unmount_removable    (NautilusVolumeMonitor      *monitor,
 									     const char                 *mount_point,
@@ -96,6 +98,7 @@ NautilusVolume          *nautilus_volume_monitor_get_volume_for_path        (Nau
 
 /* Volume operations. */
 char *                   nautilus_volume_get_name                           (const NautilusVolume       *volume);
+char *                   nautilus_volume_get_icon                           (const NautilusVolume       *volume);
 NautilusDeviceType       nautilus_volume_get_device_type                    (const NautilusVolume       *volume);
 gboolean                 nautilus_volume_is_removable                       (const NautilusVolume       *volume);
 gboolean                 nautilus_volume_is_read_only                       (const NautilusVolume       *volume);
@@ -109,6 +112,6 @@ void                     nautilus_volume_free                               (Nau
 guint                    nautilus_volume_hash                               (const NautilusVolume       *volume);
 gboolean                 nautilus_volume_is_equal                           (const NautilusVolume       *volume1,
 									     const NautilusVolume       *volume2);
-
+gboolean                 nautilus_volume_is_in_removable_blacklist          (const NautilusVolume       *volume);
 
 #endif /* NAUTILUS_VOLUME_MONITOR_H */
